# Installation

You can install `retrigen` via pip from [PyPI]:

```bash
pip install retrigen
```

or from [GitHub] using:

```bash
pip install git+https://github.com/KennethEnevoldsen/retrigen
```

[pip]: https://pip.pypa.io/en/stable/
[PyPI]: https://pypi.org/project/retrigen/
[GitHub]: https://github.com/KennethEnevoldsen/retrigen